@@ -55,6 +55,10 @@ cat(
 "sum(x)",
 "1 + (x + y)",
 "1 + ((x + y) * z)",
+"1 + (z/(x + y))",
+"1 + (z^(x + y))",
+"1 + (sum(1:10))",
+"1 + ((sum(1:10)))",
 "if (x > 0) x + y",
 "for (i in seq_along(z)) x[i] <- x[i] + 2",
 "while (x < 2) x + 2",
